@@ -3,7 +3,7 @@
 from .utils.env import setup_environment
 import sys
 
-sys.path.insert(0, 'src')
+#sys.path.insert(0, 'src')
 
 setup_environment()
 
